fnss.topologies.parsers.parse_brite — FNSS 0.7.0 documentation

# fnss.topologies.parsers.parse_brite

`parse_brite`(path, capacity_unit='Mbps', delay_unit='ms', distance_unit='Km', directed=True)

  Parse a topology from an output file generated by the BRITE topology generator

  Parameters: | path : str The path to the BRITE output file capacity_unit : str, optional The unit in which link capacity values are expresses in the BRITE file delay_unit : str, optional The unit in which link delay values are expresses in the BRITE file distance_unit : str, optional The unit in which node coordinates are expresses in the BRITE file directed : bool, optional If True, the topology is parsed as directed topology.
  Returns: | topology : Topology or DirectedTopology

  Notes

  Each node of the returned topology object is labeled with latitude and longitude attributes. These attributes are not expressed in degrees but in distance_unit.